@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.65'; # VERSION
+our $DATE = '2015-05-13'; # DATE
+our $VERSION = '0.66'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,7 +29,7 @@ $SPEC{':package'} = {
     summary => 'Get subroutine arguments from command line arguments (@ARGV)',
 };
 
-my $re_simple_scalar = qr/^(str|num|int|float|bool|buf|re)$/;
+my $re_simple_scalar = qr/^(str|num|int|float|bool|buf|re|date|duration)$/;
 
 # retun ($success?, $errmsg, $res)
 sub _parse_json {
@@ -58,13 +58,13 @@ sub _parse_json {
 
 sub _parse_yaml {
     no warnings 'once';
-    require YAML::Syck;
+    require YAML::XS;
 
     my $str = shift;
 
-    local $YAML::Syck::ImplicitTyping = 1;
+    #local $YAML::Syck::ImplicitTyping = 1;
     my $res;
-    eval { $res = YAML::Syck::Load($str) };
+    eval { $res = YAML::XS::Load($str) };
     my $e = $@;
     return (!$e, $e, $res);
 }
@@ -956,50 +956,6 @@ sub get_args_from_argv {
         }
     }
 
-    # 5. check 'args_groups'
-    {
-        last unless $strict;
-
-        last unless $meta->{args_groups};
-        my @specified_args = sort keys %$rargs;
-        for my $group_spec (@{ $meta->{args_groups} }) {
-            my $group_args = $group_spec->{args};
-            next unless @$group_args > 1;
-            my $rel = $group_spec->{rel};
-            my @args_in_group = grep {my $arg = $_; first {$_ eq $arg} @$group_args} @specified_args;
-            if ($rel eq 'one_of') {
-                next unless @args_in_group;
-                if (@args_in_group > 1) {
-                    my $first_arg = shift @args_in_group;
-                    return [
-                        400, join(
-                            "",
-                            "You specify '$first_arg', but also specify ",
-                            join(", ", map {"'$_'"} @args_in_group),
-                            " (only one can be specified)",
-                        )];
-                }
-            } elsif ($rel eq 'all') {
-                next unless @args_in_group;
-                if (@args_in_group < @$group_args) {
-                    my @missing = grep {my $arg = $_; !(first {$_ eq $arg} @specified_args)} @$group_args;
-                    return [
-                        400, join(
-                            "",
-                            "You specify ",
-                            join(", ", map {"'$_'"} @args_in_group),
-                            ", but don't specify ",
-                            join(", ", map {"'$_'"} @missing),
-                            " (they must all be specified together)",
-                        )];
-                }
-            } else {
-                die "BUG: Unknown rel '$rel' in args_groups" .
-                    ", only one_of/all is supported";
-            }
-        }
-    }
-
     #$log->tracef("<- get_args_from_argv(), args=%s, remaining argv=%s",
     #             $rargs, $argv);
     [200, "OK", $rargs, {
@@ -1023,7 +979,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.65 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-04-02.
+This document describes version 0.66 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-05-13.
 
 =head1 SYNOPSIS
 
